==> xlniuxdata-vipgame-1.0.146-sources.jar: com/xunlei/niux/data/vipgame/vo/GamePayXmlMeta.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;


/**
 * 充值配置
 * @author 李苏
 * @date 2013-06-21
 * @Descripter:
 */
@Table(tableName="gamepayxmlmeta",pkFieldName="seqid",pkFieldAssign=false)
public class GamePayXmlMeta {
	
	private Long seqid;
	private String gameId;
	private String newGameId;
	private String rechargeUrl;
	private String rechargeKey;
	private String copartnerProxy;
	private String vrySecretKey;
	private String googsname;
	private String effectpaytime;
	private String showmessage;
	private Boolean isclose;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String rolesQueryUrl;
	private String rolesKey;
	private Boolean rechargeCallType;
	private Integer rolesCallType;
	private Integer rate;
	private Integer bizType;//业务类型：0，联运 1，独代 2，手游（未使用）
	@Exclude
	private String dsName;
	public Integer getBizType() {
		return bizType;
	}

	public String getDsName() {
		return dsName;
	}

	public void setDsName(String dsName) {
		this.dsName = dsName;
	}

	public void setBizType(Integer bizType) {
		this.bizType = bizType;
	}
	public Integer getRate() {
		return rate;
	}
	public void setRate(Integer rate) {
		this.rate = rate;
	}
	public String getNewGameId() {
		return newGameId;
	}
	public void setNewGameId(String newGameId) {
		this.newGameId = newGameId;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getRechargeUrl() {
		return rechargeUrl;
	}
	public void setRechargeUrl(String rechargeUrl) {
		this.rechargeUrl = rechargeUrl;
	}
	public String getRechargeKey() {
		return rechargeKey;
	}
	public void setRechargeKey(String rechargeKey) {
		this.rechargeKey = rechargeKey;
	}
	public String getCopartnerProxy() {
		return copartnerProxy;
	}
	public void setCopartnerProxy(String copartnerProxy) {
		this.copartnerProxy = copartnerProxy;
	}
	public String getVrySecretKey() {
		return vrySecretKey;
	}
	public void setVrySecretKey(String vrySecretKey) {
		this.vrySecretKey = vrySecretKey;
	}
	public String getGoogsname() {
		return googsname;
	}
	public void setGoogsname(String googsname) {
		this.googsname = googsname;
	}
	public String getEffectpaytime() {
		return effectpaytime;
	}
	public void setEffectpaytime(String effectpaytime) {
		this.effectpaytime = effectpaytime;
	}
	public String getShowmessage() {
		return showmessage;
	}
	public void setShowmessage(String showmessage) {
		this.showmessage = showmessage;
	}
	public Boolean getIsclose() {
		return isclose;
	}
	public void setIsclose(Boolean isclose) {
		this.isclose = isclose;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	
	public Boolean getRechargeCallType() {
		return rechargeCallType;
	}
	public void setRechargeCallType(Boolean rechargeCallType) {
		this.rechargeCallType = rechargeCallType;
	}
	public Integer getRolesCallType() {
		return rolesCallType;
	}
	public void setRolesCallType(Integer rolesCallType) {
		this.rolesCallType = rolesCallType;
	}
	public String getRolesQueryUrl() {
		return rolesQueryUrl;
	}
	public void setRolesQueryUrl(String rolesQueryUrl) {
		this.rolesQueryUrl = rolesQueryUrl;
	}
	public String getRolesKey() {
		return rolesKey;
	}
	public void setRolesKey(String rolesKey) {
		this.rolesKey = rolesKey;
	}
	
}

==> xlniuxdata-vipgame-1.1.5-20190424.035512-4-sources.jar: com/xunlei/niux/data/vipgame/vo/GamePayXmlMeta.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;


/**
 * 充值配置
 * @author 李苏
 * @date 2013-06-21
 * @Descripter:
 */
@Table(tableName="gamepayxmlmeta",pkFieldName="seqid",pkFieldAssign=false)
public class GamePayXmlMeta {
	
	private Long seqid;
	private String gameId;
	private String newGameId;
	private String rechargeUrl;
	private String rechargeKey;
	private String copartnerProxy;
	private String vrySecretKey;
	private String googsname;
	private String effectpaytime;
	private String showmessage;
	private Boolean isclose;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String rolesQueryUrl;
	private String rolesKey;
	private Boolean rechargeCallType;
	private Integer rolesCallType;
	private Integer rate;
	private Integer bizType;//业务类型：0，联运 1，独代 2，手游（未使用）
	@Exclude
	private String dsName;
	@Exclude
	private String isNewDb;

	public String getIsNewDb() {
		return isNewDb;
	}

	public void setIsNewDb(String isNewDb) {
		this.isNewDb = isNewDb;
	}

	public Integer getBizType() {
		return bizType;
	}

	public String getDsName() {
		return dsName;
	}

	public void setDsName(String dsName) {
		this.dsName = dsName;
	}

	public void setBizType(Integer bizType) {
		this.bizType = bizType;
	}
	public Integer getRate() {
		return rate;
	}
	public void setRate(Integer rate) {
		this.rate = rate;
	}
	public String getNewGameId() {
		return newGameId;
	}
	public void setNewGameId(String newGameId) {
		this.newGameId = newGameId;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getRechargeUrl() {
		return rechargeUrl;
	}
	public void setRechargeUrl(String rechargeUrl) {
		this.rechargeUrl = rechargeUrl;
	}
	public String getRechargeKey() {
		return rechargeKey;
	}
	public void setRechargeKey(String rechargeKey) {
		this.rechargeKey = rechargeKey;
	}
	public String getCopartnerProxy() {
		return copartnerProxy;
	}
	public void setCopartnerProxy(String copartnerProxy) {
		this.copartnerProxy = copartnerProxy;
	}
	public String getVrySecretKey() {
		return vrySecretKey;
	}
	public void setVrySecretKey(String vrySecretKey) {
		this.vrySecretKey = vrySecretKey;
	}
	public String getGoogsname() {
		return googsname;
	}
	public void setGoogsname(String googsname) {
		this.googsname = googsname;
	}
	public String getEffectpaytime() {
		return effectpaytime;
	}
	public void setEffectpaytime(String effectpaytime) {
		this.effectpaytime = effectpaytime;
	}
	public String getShowmessage() {
		return showmessage;
	}
	public void setShowmessage(String showmessage) {
		this.showmessage = showmessage;
	}
	public Boolean getIsclose() {
		return isclose;
	}
	public void setIsclose(Boolean isclose) {
		this.isclose = isclose;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	
	public Boolean getRechargeCallType() {
		return rechargeCallType;
	}
	public void setRechargeCallType(Boolean rechargeCallType) {
		this.rechargeCallType = rechargeCallType;
	}
	public Integer getRolesCallType() {
		return rolesCallType;
	}
	public void setRolesCallType(Integer rolesCallType) {
		this.rolesCallType = rolesCallType;
	}
	public String getRolesQueryUrl() {
		return rolesQueryUrl;
	}
	public void setRolesQueryUrl(String rolesQueryUrl) {
		this.rolesQueryUrl = rolesQueryUrl;
	}
	public String getRolesKey() {
		return rolesKey;
	}
	public void setRolesKey(String rolesKey) {
		this.rolesKey = rolesKey;
	}
	
}
